%bcond_without tests
Name:             fossil
Version:          2.12.1
Release:          1%{?dist}
Summary:          A distributed SCM with bug tracking and wiki

License:          BSD
URL:              https://www.fossil-scm.org/
Source0:          %{URL}index.html/uv/fossil-src-%{version}.tar.gz

BuildRequires:    gcc-c++
BuildRequires:    zlib-devel
BuildRequires:    sqlite-devel
BuildRequires:    openssl-devel
BuildRequires:    tcl

%description
Fossil is a simple, high-reliability, distributed software configuration
management with distributed bug tracking, distributed wiki and built-in web
interface.

%package doc
Summary:          Fossil documentation

%description doc
Documentation in HTML format for %{name}.

%prep
%autosetup
rm -f src/sqlite3.c

# Update config.guess/sub to fix builds on new architectures (aarch64/ppc64le)
for conf in /usr/lib/rpm/config.*; do [ -z "${f}" ] && break; cp "${f}" autosetup; done

%build
%set_build_flags
# This gives configure-without-libdir-spec, but this is done because this is not generated by autoconf (but by autosetup)
# Because of this, it does not support the --host= argument like expected, and as such %%configure cannot be used
./configure --build=%{_build} \
  --disable-dependency-tracking \
  --prefix=%{_prefix} \
  --exec-prefix=%{_exec_prefix} \
  --bindir=%{_bindir} \
  --sbindir=%{_sbindir} \
  --sysconfdir=%{_sysconfdir} \
  --datadir=%{_datadir} \
  --includedir=%{_includedir} \
  --libdir=%{_libdir} \
  --libexecdir=%{_libexecdir} \
  --localstatedir=%{_localstatedir} \
  --sharedstatedir=%{_sharedstatedir} \
  --mandir=%{_mandir} \
  --infodir=%{_infodir} \
  --disable-internal-sqlite \
  --with-openssl=auto \
  --json

%make_build
# fix spurious-executable-perm
chmod -x www/collisions.ipynb
# fix env-script-interpreter
sed -i "s:^#\!/usr/bin/env\s\+tclsh\s\?$:#!%_bindir/tclsh:" www/mkindex.tcl

%install
%make_install
install -D -m 0644 -t %{buildroot}%{_mandir}/man1 fossil.1


%check
%if %{with tests}
tclsh test/tester.tcl %{buildroot}%{_bindir}/%name
%endif

%files
%license COPYRIGHT-BSD2.txt
%{_bindir}/%name
%{_mandir}/man1/%name.1*

%files doc
%doc www

%changelog
* Mon Oct 19 2020 Sheng Mao <shngmao@gmail.com> - 2.12.1-1
- Upgrade to fossil 2.12.1 after adding FTS4 to system-wide sqlite (rhbz#1887106)
  rhbz#1863577, rhbz#1870790

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.8-5
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jul 04 2019 Filipe Rosset <rosset.filipe@gmail.com> - 2.8-1
- Update to 2.8 fixes rhbz#1581180 rhbz#1603993 rhbz#1674893 and rhbz#1524335
- Removed upstreamed patch
- Bug 1524335 - CVE-2017-17459 fossil: Command injection via malicious ssh URLs [fedora-all]
- Bug 1581180 - Update fossil version to 2.6 (currently is 2.2)
- Bug 1603993 - fossil: FTBFS in Fedora rawhide
- Bug 1674893 - fossil: FTBFS in Fedora rawhide/f30

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Apr 28 2017 Patrick Uiterwijk <puiterwijk@redhat.com> - 2.2-2
- Update source URL
- Add patch to drop extra groups

* Fri Apr 28 2017 Patrick Uiterwijk <puiterwijk@redhat.com> - 2.2-1
- Rebase to 2.2

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.34-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun Mar 20 2016 Divya Cote <divya.hariomtatsat@gmail.com> - 1.34-1
- Update to latest release

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.33-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.33-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 27 2015 Patrick Uiterwijk <puiterwijk@redhat.com> - 1.33-1
- Update to latest release

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.28-4.20140127173344
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 16 2014 Peter Robinson <pbrobinson@fedoraproject.org> 1.28-3.20140127173344
- Update config.guess/sub to fix ftbfs on new architectures (aarch64/ppc64le)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.28-2.20140127173344
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Jan 29 2014 Patrick Uiterwijk <puiterwijk@redhat.com> - 1.28-1.20140127173344
- Update to 1.28
- Remove patch to use system sqlite

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.25-3.20130216000435
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue May 07 2013 Patrick Uiterwijk <puiterwijk@gmail.com> - 1.25-2.20130216000435
- Update file permissions for bin/fossil

* Fri May 03 2013 Patrick Uiterwijk <puiterwijk@gmail.com> - 1.25-1.20130216000435
- Update packaging

* Tue Sep 08 2009 Silas Sewell <silas@sewell.ch> - 0.0-0.2.20090828225927
- Add doc subpackage and make optflags

* Mon Sep 07 2009 Silas Sewell <silas@sewell.ch> - 0.0-0.1.20090828225927
- Initial package
